@@ -94,7 +94,7 @@ package Astro::Coord::ECI::Utils;
 use strict;
 use warnings;
 
-our $VERSION = '0.039_01';
+our $VERSION = '0.039_02';
 our @ISA = qw{Exporter};
 
 use Carp;
@@ -499,6 +499,10 @@ be time.
 sub find_first_true {
     my ($begin, $end, $test, $limit) = @_;
     $limit ||= 1;
+    defined $begin
+	or confess 'Programming error - $begin undefined';
+    defined $end
+	or confess 'Programming error - $end undefined';
     if ($limit >= 1) {
 	if ($begin <= $end) {
 	    $begin = floor ($begin);
